RouterMessage

Enum RouterMessage 

pub enum RouterMessage {
    Connect(Connection),
    Packet(Packet),
    Packets(VecDeque<Packet>),
    Death(String),
    Pending(VecDeque<Publish>),
}
Router message to orchestrate data between connections. We can also use this to send control signals to connections to modify their behavior dynamically from the console

Variants



Connect(Connection)

Client id and connection handle



Packet(Packet)

Packet



Packets(VecDeque<Packet>)

Packets



Death(String)

Disconnects a client from active connections list. Will handling



Pending(VecDeque<Publish>)

Pending messages of the previous connection